@@ -102,7 +102,9 @@ void DiscoverPage::startScan()
     deviceList->clear();
     stopScan();
 
-    Manager::self()->defaultAdapter()->startDiscovery();
+    if (Manager::self()->defaultAdapter()) {
+        Manager::self()->defaultAdapter()->startDiscovery();
+    }
 }
 
 void DiscoverPage::stopScan()
@@ -160,6 +162,12 @@ void DiscoverPage::deviceFound(const QVariantMap &deviceInfo)
         deviceList->setCurrentItem(m_itemRelation[address]);
         itemSelected(m_itemRelation[address]);
     }
+
+    //If the device has been preselected via arguments, select it
+    if (m_wizard->preselectedAddress() == address.toLower()) {
+        deviceList->setCurrentItem(m_itemRelation[address]);
+        itemSelected(m_itemRelation[address]);
+    }
 }
 
 void DiscoverPage::itemSelected(QListWidgetItem* item)
